@@ -409,10 +409,12 @@ def mergeReports(args):
     mergedStat = open('%s/%s/%s/report_summary.txt' % (outDir, coreSet, queryID), 'w')
     mergedStat.write('mode\tgenomeID\tsimilar\tdissimilar\tduplicated\tmissing\tignored\ttotal\n')
     mergedFull = open('%s/%s/%s/report_full.txt' % (outDir, coreSet, queryID), 'w')
+    mergedDismiss = open('%s/%s/%s/report_dismiss.txt' % (outDir, coreSet, queryID), 'w')
     fullTypeDict = {}
+    dismissTypeDict = {}
     availableMode = []
     for m in modes:
-        availableMode.append('%s_cat\t%s_value\t%s_cutoff' % (m,m,m))
+        availableMode.append('%s_cat\t%s_value\t%s_cutoff\t%s_delta' % (m,m,m,m))
         if os.path.exists('%s/%s/%s/%s/summary.txt' % (outDir, coreSet, queryID, m)):
             for line in readFile('%s/%s/%s/%s/summary.txt' % (outDir, coreSet, queryID, m)):
                 if not line.split('\t')[0] == 'genomeID':
@@ -424,17 +426,25 @@ def mergeReports(args):
                     orthoID = 'NA'
                     value = 'NA'
                     cutoff = 'NA'
+                    delta = 'NA'
                     if len(tmp) == 5:
                         orthoID = tmp[2]
                         value = tmp[-2]
                         cutoff = tmp[-1]
+                        delta = abs(float(value) - float(cutoff.split(' ')[0]))
                     key = '%s\t%s' % (tmp[0], orthoID)
                     if not key in fullTypeDict:
                         fullTypeDict[key] = []
-                    fullTypeDict[key].append('%s\t%s\t%s' % (tmp[1], value, cutoff))
+                    fullTypeDict[key].append('%s\t%s\t%s\t%s' % (tmp[1], value, cutoff, delta))
+                    if tmp[1] == 'missing' or tmp[1] == 'dissimilar' or tmp[1] == 'fragmented':
+                        dismissTypeDict[key] = 1
+
     mergedFull.write('groupID\torthoID\t%s\n' % '\t'.join(availableMode))
+    mergedDismiss.write('groupID\torthoID\t%s\n' % '\t'.join(availableMode))
     for gid in fullTypeDict:
         mergedFull.write('%s\t%s\n' % (gid, '\t'.join(fullTypeDict[gid])))
+        if gid in dismissTypeDict:
+            mergedDismiss.write('%s\t%s\n' % (gid, '\t'.join(fullTypeDict[gid])))
     mergedStat.close()
     mergedFull.close()
     # delete report for singe mode
@@ -476,7 +486,7 @@ def assessCompteness(args):
     return(flag)
 
 def main():
-    version = '0.0.20'
+    version = '0.0.22'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
